==> tool-sql-2.6.0-sources.jar: io/ciera/tool/sql/ooaofooa/component/ExecutablePropertySet.java <==
package io.ciera.tool.sql.ooaofooa.component;


import io.ciera.runtime.summit.classes.IInstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.component.C_ISet;
import io.ciera.tool.sql.ooaofooa.component.InterfaceOperationSet;
import io.ciera.tool.sql.ooaofooa.component.InterfaceSignalSet;
import io.ciera.tool.sql.ooaofooa.component.PropertyParameterSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredExecutablePropertySet;

import ooaofooa.datatypes.IFDirectionType;


public interface ExecutablePropertySet extends IInstanceSet<ExecutablePropertySet,ExecutableProperty> {

    // attributes
    public void setName( String m_Name ) throws XtumlException;
    public void setId( UniqueId m_Id ) throws XtumlException;
    public void setNumb( int m_Numb ) throws XtumlException;
    public void setDirection( IFDirectionType m_Direction ) throws XtumlException;
    public void setInterface_Id( UniqueId ref_Interface_Id ) throws XtumlException;
    public void setDescrip( String m_Descrip ) throws XtumlException;


    // selections
    public C_ISet R4003_provides_signature_of_C_I() throws XtumlException;
    public InterfaceOperationSet R4004_is_a_InterfaceOperation() throws XtumlException;
    public InterfaceSignalSet R4004_is_a_InterfaceSignal() throws XtumlException;
    public PropertyParameterSet R4006_is_parameter_to_PropertyParameter() throws XtumlException;
    public RequiredExecutablePropertySet R4500_is_implemented_by_RequiredExecutableProperty() throws XtumlException;
    public ProvidedExecutablePropertySet R4501_is_implemented_by_ProvidedExecutableProperty() throws XtumlException;


}

==> tool-sql-2.7.0-sources.jar: io/ciera/tool/sql/ooaofooa/component/ExecutablePropertySet.java <==
package io.ciera.tool.sql.ooaofooa.component;


import io.ciera.runtime.summit.classes.IInstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.architecture.interfaces.MessageSet;
import io.ciera.tool.sql.ooaofooa.component.C_ISet;
import io.ciera.tool.sql.ooaofooa.component.InterfaceOperationSet;
import io.ciera.tool.sql.ooaofooa.component.InterfaceSignalSet;
import io.ciera.tool.sql.ooaofooa.component.PropertyParameterSet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.ProvidedExecutablePropertySet;
import io.ciera.tool.sql.ooaofooa.component.signalprovisionsandrequirements.RequiredExecutablePropertySet;

import ooaofooa.datatypes.IFDirectionType;


public interface ExecutablePropertySet extends IInstanceSet<ExecutablePropertySet,ExecutableProperty> {

    // attributes
    public void setDirection( IFDirectionType m_Direction ) throws XtumlException;
    public void setInterface_Id( UniqueId ref_Interface_Id ) throws XtumlException;
    public void setId( UniqueId m_Id ) throws XtumlException;
    public void setName( String m_Name ) throws XtumlException;
    public void setNumb( int m_Numb ) throws XtumlException;
    public void setDescrip( String m_Descrip ) throws XtumlException;


    // selections
    public C_ISet R4003_provides_signature_of_C_I() throws XtumlException;
    public InterfaceOperationSet R4004_is_a_InterfaceOperation() throws XtumlException;
    public InterfaceSignalSet R4004_is_a_InterfaceSignal() throws XtumlException;
    public PropertyParameterSet R4006_is_parameter_to_PropertyParameter() throws XtumlException;
    public RequiredExecutablePropertySet R4500_is_implemented_by_RequiredExecutableProperty() throws XtumlException;
    public ProvidedExecutablePropertySet R4501_is_implemented_by_ProvidedExecutableProperty() throws XtumlException;
    public MessageSet R4761_Message() throws XtumlException;


}
